==> ReCAP-Utils-0.1.15.tar.gz: ReCAP-Utils-0.1.15/recap_utils/model.py <==
from __future__ import annotations

import typing as t
from dataclasses import dataclass
from pathlib import Path


@dataclass
class PathPair:
    """A pair of paths for modification of files."""

    source: Path
    target: Path

    @classmethod
    def create(
        cls,
        path_in: Path,
        path_out: Path,
        suffix_in: t.Optional[str],
        suffix_out: t.Optional[str],
    ) -> t.List[PathPair]:
        if path_in.is_file() and path_out.is_file():
            return [cls(path_in, path_out)]

        elif path_in.is_dir() and path_out.is_dir() and suffix_in and suffix_out:
            files_in = sorted(path_in.rglob(f"*{suffix_in}"))
            files_out = []

            for file_in in files_in:
                file_out = path_out / file_in.relative_to(path_in)
                file_out = file_out.with_suffix(suffix_out)
                file_out.parent.mkdir(parents=True, exist_ok=True)

                files_out.append(file_out)

            return [
                cls(file_in, file_out) for file_in, file_out in zip(files_in, files_out)
            ]

        raise ValueError("Wrong combination of parameters given.")

    @staticmethod
    def label(path_pair: t.Optional[PathPair]) -> str:
        """Generate a string for representing a path pair.

        Args:
            path_pair: The item that should be represented.

        Returns:
            A label for use in UI contexts.
        """

        if path_pair:
            return path_pair.source.name
        return ""

==> ReCAP-Utils-0.1.18.tar.gz: ReCAP-Utils-0.1.18/recap_utils/model.py <==
from __future__ import annotations

import typing as t
from dataclasses import dataclass
from pathlib import Path


@dataclass
class PathPair:
    """A pair of paths for modification of files."""

    source: Path
    target: Path

    @classmethod
    def create(
        cls,
        path_in: Path,
        path_out: Path,
        suffix_in: t.Optional[str],
        suffix_out: t.Optional[str],
    ) -> t.List[PathPair]:
        if path_in.is_file():
            return [cls(path_in, path_out)]

        elif path_in.is_dir() and path_out.is_dir() and suffix_in and suffix_out:
            files_in = sorted(path_in.rglob(f"*{suffix_in}"))
            files_out = []

            for file_in in files_in:
                file_out = path_out / file_in.relative_to(path_in)
                file_out = file_out.with_suffix(suffix_out)
                file_out.parent.mkdir(parents=True, exist_ok=True)

                files_out.append(file_out)

            return [
                cls(file_in, file_out) for file_in, file_out in zip(files_in, files_out)
            ]

        raise ValueError("Wrong combination of parameters given.")

    @staticmethod
    def label(path_pair: t.Optional[PathPair]) -> str:
        """Generate a string for representing a path pair.

        Args:
            path_pair: The item that should be represented.

        Returns:
            A label for use in UI contexts.
        """

        if path_pair:
            return path_pair.source.name
        return ""
